@@ -1,5 +1,18 @@
-#! /usr/bin/env python
-# encoding: utf-8
+# This file is part of sympy2c.
+#
+# Copyright (C) 2013-2021 ETH Zurich, Institute for Particle and Astrophysics and SIS
+# ID.
+#
+# This program is free software: you can redistribute it and/or modify it under the
+# terms of the GNU General Public License as published by the Free Software Foundation,
+# either version 3 of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with this
+# program.  If not, see <http://www.gnu.org/licenses/>.
 
 import glob
 import hashlib
@@ -217,10 +230,7 @@ def create_source_files(
         compilation_flags = ["-O3"]
 
     setup_py_content = align(
-        """#! /usr/bin/env python
-    |# encoding: utf-8
-    |
-
+        """
     |from distutils.core import setup
     |from distutils.extension import Extension
     |from distutils.sysconfig import get_config_vars
